@@ -6,17 +6,18 @@ __version__ = get_distribution("pyplatform-datawarehouse").version
 
 
 def show_me(module=None, docstring=False):
-    """Print functions contained in a module or script.
+    """
+    Print functions contained in a module or script.
 
     Keyword Arguments:
-        module {str,os.path,types.ModuleType} -- module, submodule or scriptpath (default=pyplatform)
+        module {str,os.path,types.ModuleType} -- module, submodule or scriptpath (default=None)
         doctring {bool} -- if true, prints doctring of functions as well (default=False)
 
     Example:
     import pyplatform.common as pyp
     pyp.show_me() # prints functions names contained in pyplatfrom
 
-    from pyplatform import udf
+    from pyplatform.common import udf
     pyp.show_me(udf, docstring=True) # prints functions names contained in udf submodule with docstring
 
     pyp.show_me('path_to_script/main.py') #prints funcstion contained in main.py
@@ -26,9 +27,9 @@ def show_me(module=None, docstring=False):
     import os
     from types import ModuleType
 
-    module_pattern = re.compile(r'^([a-z]*.py)')
-    functions = re.compile('^def.*|^###.*')
-    all_content = re.compile('^def.*|^###.*|^s*"""|.*"""')
+    module_pattern = re.compile(r'^([a-z0-9]*.py)')
+    functions = re.compile('^def[^__]{2}.*')
+    all_content = re.compile('^def[^__]{2}.*|^[\s]*\"\"\"[\s]*.{1}')
 
     if not module:
         module_dir = os.path.dirname(__file__)
@@ -36,20 +37,29 @@ def show_me(module=None, docstring=False):
                        for script in os.listdir(module_dir) if re.search(module_pattern, script)]
 
     elif isinstance(module, ModuleType):
-        if os.path.basename(module.__file__) != '__init__.py':
-            script_path = [module.__file__]
+        if re.search(r'(namespace)', repr(module)):
+            module_dir = module.__path__._path[0]
+            script_path = [os.path.join(path, name) for path, subdirs, files in os.walk(
+                module_dir) for name in files if re.search(r'[^__].py$', name)]
+
         else:
-            module_dir = os.path.dirname(module.__file__)
-            script_path = [os.path.join(module_dir, script)
-                           for script in os.listdir(module_dir) if re.search(module_pattern, script)]
+            if os.path.basename(module.__file__) != '__init__.py':
+                script_path = [module.__file__]
+            else:
+                module_dir = os.path.dirname(module.__file__)
+                script_path = [os.path.join(module_dir, script)
+                               for script in os.listdir(module_dir) if re.search(module_pattern, script)]
 
     elif os.path.isfile(module):
         script_path = [module]
 
     for file_path in script_path:
+        print('\n')
 
         print("***", "==="*5, '      ', os.path.basename(file_path).split('.')[0],
               '       ', "==="*5, "***", '\n')
+        if docstring:
+            print(f'{os.path.basename(file_path)} at {file_path} contains: \n')
         lines = None
         with open(file_path, mode='r') as file:
             lines = file.readlines()
@@ -61,4 +71,4 @@ def show_me(module=None, docstring=False):
             else:
                 if re.search(functions, line):
                     print(line)
-        print('\n'*2)
+        print('\n')
